diff --git a/emacs/notmuch-show.el b/emacs/notmuch-show.el
index 78f1af47..18cbc690 100644
--- a/emacs/notmuch-show.el
+++ b/emacs/notmuch-show.el
@@ -744,6 +744,11 @@ will return nil if the CID is unknown or cannot be retrieved."
     (save-excursion
       (save-restriction
 	(narrow-to-region start (point-max))
+	;; XXX dme: It would be much nicer to do this using a wash
+	;; function attached to the hook, but that doesn't currently
+	;; get access to the part and so cannot check the format.
+	(when (string= (plist-get part :format) "flowed")
+	  (fill-flowed))
 	(run-hook-with-args 'notmuch-show-insert-text/plain-hook msg depth))))
   t)
 
diff --git a/notmuch-show.c b/notmuch-show.c
index 07e9a5db..92d18bb8 100644
--- a/notmuch-show.c
+++ b/notmuch-show.c
@@ -708,6 +708,19 @@ format_part_sprinter (const void *ctx, sprinter_t *sp, mime_node_t *node,
     }
 
     if (GMIME_IS_PART (node->part)) {
+	/* Include the format parameter of text/plain parts if it
+	 * exists, allowing the UI to adapt the display of the part as
+	 * appropriate.
+	 */
+	if (g_mime_content_type_is_type (content_type, "text", "plain")) {
+	    const char *format =
+		g_mime_object_get_content_type_parameter (node->part, "format");
+	    if (format) {
+		sp->map_key (sp, "format");
+		sp->string (sp, format);
+	    }
+	}
+
 	/* For non-HTML text parts, we include the content in the
 	 * JSON. Since JSON must be Unicode, we handle charset
 	 * decoding here and do not report a charset to the caller.
